@@ -1,8 +1,14 @@
+# builtins
 import os
 import datetime
 import logging
+
+
+# third party modules
 import pyhcup
 
+
+# django modules
 from django.utils.timezone import utc
 from django.db import models
 from django.db.models import Q
@@ -10,16 +16,20 @@ from django.utils.html import escape
 from django.core.urlresolvers import reverse
 from django.conf import settings
 
+
+# local project modules
+from djhcup_core.utils import get_pgcnxn
 from djhcup_core.defaults import DATETIME_FORMAT
 
+
 # set some constants
 ALLOWED_LOG_LEVELS = ['NOTSET', 'DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL']
-HACHOIR_DB_ENTRY = 'djhcup'
-DB_DEF = settings.DATABASES[HACHOIR_DB_ENTRY]
+
 
 # start a logger
 default_logger = logging.getLogger('default')
 
+
 # Create your models here.
 class State(models.Model):
     abbreviation = models.CharField(max_length=2, blank=False,
@@ -809,17 +819,7 @@ class StagingTable(models.Model):
     # overwrite method to drop table as well by default
     def delete(self, drop_table=True, *args, **kwargs):
         if drop_table:
-            # establish connection directly with psycopg2
-            #DB_BACKEND = DB_DEF['ENGINE'].split('.')[-1]
-            
-            import psycopg2
-            cnxn = psycopg2.connect(
-                host=DB_DEF['HOST'],
-                port=DB_DEF['PORT'],
-                user=DB_DEF['USER'],
-                password=DB_DEF['PASSWORD'],
-                database=DB_DEF['NAME'],
-                )
+            cnxn = get_pgcnxn()
             drop_result = pyhcup.db.pg_drop(cnxn, self.name)
             if drop_result == True:
                 default_logger.info('Dropped table {table} from database'.format(table=self.name))
