@@ -545,10 +545,19 @@ def pg_stage(self, stagingqueue_pk):
         cursor = cnxn.cursor()
         
         # set aside info about the related ImportQueue object
-        state = stg_input.state
+        try:
+            state = stg_input.state
+            load = stg_input.imported_via
+            meta = load.get_meta()
+            year = stg_input.year
+        except:
+            if 'stg_tx' in input_tbl:
+                state = 'TX'
+                year = input_tbl.split('_')[2]
+            else:
+                raise
+        
         year = stg_input.year
-        load = stg_input.imported_via
-        meta = load.get_meta()
         
         # generate the destination table name
         output_tbl = '_'.join(str(x) for x in ['stg', state, year, category, now_hr]).lower()
