@@ -21,6 +21,7 @@ from django.core.exceptions import ObjectDoesNotExist
 from django.db import connections as cnxns
 from django.db import transaction as tx
 from django.db.models import Q
+from django.contrib.auth.decorators import login_required
 
 
 # local project and app packages
@@ -42,6 +43,7 @@ logger = logging.getLogger('default')
 
 
 # Create your views here.
+@login_required(login_url='/login/')
 def index(request):
     logger.debug('Index requested')
     
@@ -81,6 +83,7 @@ ALLOWED_OBJ_DETAIL = [
 ]
 
 
+@login_required(login_url='/login/')
 def obj_detail(request, obj_id, obj_type, msg_pt=[]): 
     logger.debug('Detail requested for obj_type {t} and pk {pk}.'\
         .format(t=obj_type, pk=obj_id))
@@ -161,6 +164,7 @@ def obj_detail(request, obj_id, obj_type, msg_pt=[]):
     return render(request, template, context)
 
 
+@login_required(login_url='/login/')
 def obj_inventory(request, obj_type, msg_pt=[], *args, **kwargs):    
     logger.debug('Inventory requested for obj_type {t}.'\
         .format(t=obj_type))
@@ -295,6 +299,7 @@ def obj_inventory(request, obj_type, msg_pt=[], *args, **kwargs):
     return render(request, template, context)
 
 
+@login_required(login_url='/login/')
 def run_batch(request, obj_id, obj_type):
     logger.debug('run_batch requested for obj_type {t} #{pk}'\
         .format(t=obj_type, pk=obj_id))
@@ -323,6 +328,7 @@ def run_batch(request, obj_id, obj_type):
         return obj_detail(request, obj_id, obj_type, msg_pt=[response])
 
 
+@login_required(login_url='/login/')
 def create_batch_from_unimported(request):
     b = staging.unimported_batch()
     
@@ -332,6 +338,7 @@ def create_batch_from_unimported(request):
     return importbatch_inventory(request, msg_pass_through=[message])
 
 
+@login_required(login_url='/login/')
 def batch_from_unprocessed(request):
     b = staging.unprocessed_batches()
     
@@ -342,6 +349,7 @@ def batch_from_unprocessed(request):
     #return importbatch_inventory(request, msg_pass_through=messages)
 
 
+@login_required(login_url='/login/')
 def batch_reset_dead(request):
     """Dispatches a celery task to reset interrupted ImportBatch objects and their associated ImportQueue objects.
     """
@@ -361,6 +369,7 @@ def batch_reset_dead(request):
     return render(request, template, context)
 
 
+@login_required(login_url='/login/')
 def source_populate_defaults(request):
     """Generate source definitions, patterns, etc. using defaults in utils.defaults
     """
@@ -401,6 +410,7 @@ def source_populate_defaults(request):
     return render(request, template, context)
 
 
+@login_required(login_url='/login/')
 def file_discover(request):
     messages = []
     discovered = []
@@ -493,6 +503,7 @@ def file_discover(request):
     return obj_inventory(request, 'File', msg_pass_through=messages)
 
 
+@login_required(login_url='/login/')
 def file_match(request):
     messages = []
     #grab all known files and split them into content vs load files
